/*
 * Copyright 2013-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.example.demo.demos.web.controller;

import com.alibaba.fastjson.JSON;
import com.example.demo.model.Response;
import com.example.demo.model.User;
import com.example.demo.service.BasicService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import java.util.Enumeration;
import java.util.Map;

/**
 * @author <a href="mailto:chenxilzx1@gmail.com">theonefx</a>
 */
@RestController
@Slf4j
public class BasicController {
    @Autowired
    BasicService basicService;

    // http://127.0.0.1:8080/hello?name=lisi
    @PostMapping("/getElectricityInfo")
    @ResponseBody
    public Response getElectricityInfo(@RequestBody Map<String,Object> param) {
        log.info("获取电费相关信息入参：{}", JSON.toJSONString(param));
        Response response = basicService.getElectricityInfo(param);
        log.info("获取电费相关信息响应：{}", JSON.toJSONString(response));
        return response;
    }
    @PostMapping("/getElectricityInfo1")
    @ResponseBody
    public Object getElectricityInfo1(@RequestBody Map<String,Object> param) {
        log.info("获取电费相关1信息入参：{}", JSON.toJSONString(param));
        Object response = basicService.getElectricityInfo1(param);
        log.info("获取电费相关1信息入参：{}", JSON.toJSONString(response));
        return response;
    }

    @PostMapping("/getBindingInfo")
    @ResponseBody
    public Object getBindingInfo(HttpServletRequest request) {
        log.info("获取绑定信息入参：token={}，地区编码：{}", request.getHeader("x_auth_token"),request.getHeader("areaCode"));
        Object response = basicService.getBindingInfo();
        log.info("获取绑定信息入参：{}", JSON.toJSONString(response));
        return response;
    }

    // http://127.0.0.1:8080/user
    @RequestMapping("/user")
    @ResponseBody
    public User user() {
        User user = new User();
        user.setName("theonefx");
        user.setAge(666);
        return user;
    }

    // http://127.0.0.1:8080/save_user?name=newName&age=11
    @RequestMapping("/save_user")
    @ResponseBody
    public String saveUser(User u) {
        return "user will save: name=" + u.getName() + ", age=" + u.getAge();
    }

    // http://127.0.0.1:8080/html
    @RequestMapping("/html")
    public String html(){
        return "index.html";
    }

    @ModelAttribute
    public void parseUser(@RequestParam(name = "name", defaultValue = "unknown user") String name
            , @RequestParam(name = "age", defaultValue = "12") Integer age, User user) {
        user.setName("zhangsan");
        user.setAge(18);
    }
}
